@@ -22,14 +22,16 @@ class JsonSecret(CachedSpam):
         with open(self.secret_file, "rb") as f:
             self.data = json.loads(strip_comments(f.read().decode("utf-8")))
 
-    def set(self, json_path, value):
+    def set(self, json_path: str, value):
         set_value(self.data, json_path, value)
-        json.dump(self.data, self.secret_file,
-                  pretty=True, ensure_ascii=False, overwrite=True, verbose=False)
+        json.dump(
+            self.data, self.secret_file,
+            pretty=True, ensure_ascii=False, overwrite=True, verbose=False,
+        )
 
-    def get(self, json_path):
+    def get(self, json_path: str):
         return get_value(self.data, json_path)
 
 
-    def unset(self, json_path):
+    def unset(self, json_path: str):
         return del_key(self.data, json_path)
